@@ -1,7 +1,7 @@
 package Dancer::Session;
 our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: session engine for the Dancer framework
-$Dancer::Session::VERSION = '1.3510';
+$Dancer::Session::VERSION = '1.3512';
 use strict;
 use warnings;
 
@@ -29,12 +29,21 @@ sub get_current_session {
     my $session = undef;
     my $class   = ref(engine);
 
+    my $sessions = Dancer::SharedData->sessions || {};
+    my $name    = $class->session_name();
+    if ($sid and $session = $sessions->{$name}{$sid}) {
+        return $session;
+    }
+    
     $session = $class->retrieve($sid) if $sid;
 
     if (not defined $session) {
         $session = $class->create();
     }
 
+    $sessions->{$name}{$session->id} = $session;
+    Dancer::SharedData->sessions($sessions);
+
     # Generate a session cookie; we want to do this regardless of whether the
     # session is new or existing, so that the cookie expiry is updated.
     engine->write_session_id($session->id)
@@ -80,7 +89,7 @@ Dancer::Session - session engine for the Dancer framework
 
 =head1 VERSION
 
-version 1.3510
+version 1.3512
 
 =head1 DESCRIPTION
 
